Module: Google::Cloud::Kms::Inventory
- Defined in:
- lib/google/cloud/kms/inventory.rb,
lib/google/cloud/kms/inventory/version.rb
Constant Summary collapse
- VERSION =
"1.5.0"
Class Method Summary collapse
-
.configure {|::Google::Cloud.configure.kms_inventory| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-kms-inventory library.
-
.key_dashboard_service(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for KeyDashboardService.
-
.key_dashboard_service_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the KeyDashboardService service is supported by the current client.
-
.key_tracking_service(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for KeyTrackingService.
-
.key_tracking_service_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the KeyTrackingService service is supported by the current client.
Class Method Details
.configure {|::Google::Cloud.configure.kms_inventory| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-kms-inventory library.
The following configuration parameters are supported:
credentials(type:String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.lib_name(type:String) - The library name as recorded in instrumentation and logging.lib_version(type:String) - The library version as recorded in instrumentation and logging.interceptors(type:Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.timeout(type:Numeric) - Default timeout in seconds.metadata(type:Hash{Symbol=>String}) - Additional headers to be sent with the call.retry_policy(type:Hash) - The retry policy. The value is a hash with the following keys::initial_delay(type:Numeric) - The initial delay in seconds.:max_delay(type:Numeric) - The max delay in seconds.:multiplier(type:Numeric) - The incremental backoff multiplier.:jitter(type:Numeric) - The jitter in seconds. Default: 1.0.:retry_codes(type:Array<String>) - The error codes that should trigger a retry.
219 220 221 222 223 |
# File 'lib/google/cloud/kms/inventory.rb', line 219 def self.configure yield ::Google::Cloud.configure.kms_inventory if block_given? ::Google::Cloud.configure.kms_inventory end |
.key_dashboard_service(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for KeyDashboardService.
By default, this returns an instance of
Google::Cloud::Kms::Inventory::V1::KeyDashboardService::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the KeyDashboardService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the KeyDashboardService service. You can determine whether the method will succeed by calling key_dashboard_service_available?.
About KeyDashboardService
Provides a cross-region view of all Cloud KMS keys in a given Cloud project.
76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/google/cloud/kms/inventory.rb', line 76 def self.key_dashboard_service version: :v1, transport: :grpc, &block require "google/cloud/kms/inventory/#{version.to_s.downcase}" package_name = Google::Cloud::Kms::Inventory .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::Kms::Inventory.const_get(package_name).const_get(:KeyDashboardService) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.key_dashboard_service_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the KeyDashboardService service is supported by the current client. If true, you can retrieve a client object by calling key_dashboard_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the KeyDashboardService service, or if the versioned client gem needs an update to support the KeyDashboardService service.
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/google/cloud/kms/inventory.rb', line 100 def self.key_dashboard_service_available? version: :v1, transport: :grpc require "google/cloud/kms/inventory/#{version.to_s.downcase}" package_name = Google::Cloud::Kms::Inventory .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::Kms::Inventory.const_get package_name return false unless service_module.const_defined? :KeyDashboardService service_module = service_module.const_get :KeyDashboardService if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |
.key_tracking_service(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for KeyTrackingService.
By default, this returns an instance of
Google::Cloud::Kms::Inventory::V1::KeyTrackingService::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the KeyTrackingService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the KeyTrackingService service. You can determine whether the method will succeed by calling key_tracking_service_available?.
About KeyTrackingService
Returns information about the resources in an org that are protected by a given Cloud KMS key via CMEK.
147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/google/cloud/kms/inventory.rb', line 147 def self.key_tracking_service version: :v1, transport: :grpc, &block require "google/cloud/kms/inventory/#{version.to_s.downcase}" package_name = Google::Cloud::Kms::Inventory .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::Kms::Inventory.const_get(package_name).const_get(:KeyTrackingService) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.key_tracking_service_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the KeyTrackingService service is supported by the current client. If true, you can retrieve a client object by calling key_tracking_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the KeyTrackingService service, or if the versioned client gem needs an update to support the KeyTrackingService service.
171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/google/cloud/kms/inventory.rb', line 171 def self.key_tracking_service_available? version: :v1, transport: :grpc require "google/cloud/kms/inventory/#{version.to_s.downcase}" package_name = Google::Cloud::Kms::Inventory .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::Kms::Inventory.const_get package_name return false unless service_module.const_defined? :KeyTrackingService service_module = service_module.const_get :KeyTrackingService if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |